@@ -49,7 +49,7 @@ import javax.annotation.Nullable;
  * @author <a href="mailto:fredrik@westermarck.com">Fredrik Westermarck</a>
  * @author Holger Krauth
  * @author <a href="mailto:alex@purpletech.com">Alexander Day Chaffee</a>
- * @version $Id: StringUtils.java 1402496 2012-10-26 13:00:39Z rfscholte $
+ * @version $Id: StringUtils.java 1670518 2015-03-31 23:38:42Z hboutemy $
  * 
  */
 @SuppressWarnings( "JavaDoc" )
@@ -79,7 +79,7 @@ public class StringUtils
      * @return the trimmed text (never <code>null</code>)
      * @see java.lang.String#trim()
      */
-    public @Nonnull static String clean( String str )
+    @Nonnull public static String clean( String str )
     {
         return ( str == null ? "" : str.trim() );
     }
@@ -108,7 +108,7 @@ public class StringUtils
      * @return the String without whitespaces
      * @throws NullPointerException
      */
-    public @Nonnull static String deleteWhitespace( @Nonnull String str )
+    @Nonnull public static String deleteWhitespace( @Nonnull String str )
     {
         StringBuilder buffer = new StringBuilder();
         int sz = str.length();
@@ -129,7 +129,7 @@ public class StringUtils
      * @param str the String to check
      * @return true if the String is non-null, and not length zero
      */
-    public static boolean isNotEmpty( String str )
+    public static boolean isNotEmpty( @Nullable String str )
     {
         return ( ( str != null ) && ( str.length() > 0 ) );
     }
@@ -170,7 +170,9 @@ public class StringUtils
     public static boolean isBlank( @Nullable String str )
     {
         int strLen;
+        // CHECKSTYLE_OFF: InnerAssignment
         if ( str == null || ( strLen = str.length() ) == 0 )
+        // CHECKSTYLE_ON: InnerAssignment
         {
             return true;
         }
@@ -510,7 +512,7 @@ public class StringUtils
      * @param str the String to parse
      * @return an array of parsed Strings
      */
-    public @Nonnull static String[] split( @Nonnull String str )
+    @Nonnull public static String[] split( @Nonnull String str )
     {
         return split( str, null, -1 );
     }
@@ -518,7 +520,7 @@ public class StringUtils
     /**
      * @see #split(String, String, int)
      */
-    public @Nonnull static String[] split( @Nonnull String text, String separator )
+    @Nonnull public static String[] split( @Nonnull String text, @Nullable String separator )
     {
         return split( text, separator, -1 );
     }
@@ -541,7 +543,7 @@ public class StringUtils
      *                  array.  A zero or negative value implies no limit.
      * @return an array of parsed Strings
      */
-    public @Nonnull static String[] split( @Nonnull String str, String separator, int max )
+    @Nonnull public static String[] split( @Nonnull String str, @Nullable String separator, int max )
     {
         StringTokenizer tok;
         if ( separator == null )
@@ -599,7 +601,7 @@ public class StringUtils
      * @param array the array of values to concatenate.
      * @return the concatenated string.
      */
-    public @Nonnull static String concatenate( @Nonnull Object... array )
+    @Nonnull public static String concatenate( @Nonnull Object... array )
     {
         return join( array, "" );
     }
@@ -615,7 +617,7 @@ public class StringUtils
      * @param separator the separator character to use
      * @return the joined String
      */
-    public @Nonnull static String join( @Nonnull Object[] array, String separator )
+    @Nonnull public static String join( @Nonnull Object[] array, @Nullable String separator )
     {
         if ( separator == null )
         {
@@ -647,7 +649,7 @@ public class StringUtils
      * @param separator the separator character to use
      * @return the joined String
      */
-    public @Nonnull static String join( @Nonnull Iterator<?> iterator, String separator )
+    @Nonnull public static String join( @Nonnull Iterator<?> iterator, String separator )
     {
         if ( separator == null )
         {
@@ -772,7 +774,7 @@ public class StringUtils
         int start = 0, end;
         while ( ( end = text.indexOf( repl, start ) ) != -1 )
         {
-            buf.append( text.substring( start, end ) ).append( with );
+            buf.append( text, start, end ).append( with );
             start = end + repl.length();
 
             if ( --max == 0 )
@@ -780,7 +782,7 @@ public class StringUtils
                 break;
             }
         }
-        buf.append( text.substring( start ) );
+        buf.append( text, start, text.length() );
         return buf.toString();
     }
 
@@ -795,13 +797,17 @@ public class StringUtils
      * @throws NullPointerException if text or overlay is <code>null</code>
      */
     @SuppressWarnings( "ConstantConditions" )
-    public @Nonnull static String overlayString( @Nonnull String text, @Nonnull String overlay, int start, int end )
+    @Nonnull public static String overlayString( @Nonnull String text, @Nonnull String overlay, int start, int end )
     {
         if ( overlay == null )
         {
             throw new NullPointerException( "overlay is null" );
         }
-        return text.substring( 0, start ) + overlay + text.substring( end );
+        return new StringBuilder( start + overlay.length() + text.length() - end + 1 )
+            .append( text, 0, start  )
+            .append( overlay )
+            .append( text, end, text.length() )
+            .toString();
     }
 
     // Centering
@@ -818,7 +824,7 @@ public class StringUtils
      * @return String containing centered String
      * @throws NullPointerException if str is <code>null</code>
      */
-    public @Nonnull static String center( @Nonnull String str, int size )
+    @Nonnull public static String center( @Nonnull String str, int size )
     {
         return center( str, size, " " );
     }
@@ -835,7 +841,7 @@ public class StringUtils
      * @throws NullPointerException if str or delim is <code>null</code>
      * @throws ArithmeticException  if delim is the empty String
      */
-    public @Nonnull static String center( @Nonnull String str, int size, @Nonnull String delim )
+    @Nonnull public static String center( @Nonnull String str, int size, @Nonnull String delim )
     {
         int sz = str.length();
         int p = size - sz;
@@ -858,7 +864,7 @@ public class StringUtils
      * @return String without chomped newline
      * @throws NullPointerException if str is <code>null</code>
      */
-    public @Nonnull static String chomp( @Nonnull String str )
+    @Nonnull public static String chomp( @Nonnull String str )
     {
         return chomp( str, "\n" );
     }
@@ -872,7 +878,7 @@ public class StringUtils
      * @return String without chomped ending
      * @throws NullPointerException if str or sep is <code>null</code>
      */
-    public @Nonnull static String chomp( @Nonnull String str, @Nonnull String sep )
+    @Nonnull public static String chomp( @Nonnull String str, @Nonnull String sep )
     {
         int idx = str.lastIndexOf( sep );
         if ( idx != -1 )
@@ -893,7 +899,7 @@ public class StringUtils
      * @return String without chomped ending
      * @throws NullPointerException if str is <code>null</code>
      */
-    public @Nonnull static String chompLast( @Nonnull String str )
+    @Nonnull public static String chompLast( @Nonnull String str )
     {
         return chompLast( str, "\n" );
     }
@@ -906,7 +912,7 @@ public class StringUtils
      * @return String without chomped ending
      * @throws NullPointerException if str or sep is <code>null</code>
      */
-    public @Nonnull static String chompLast( @Nonnull String str, @Nonnull String sep )
+    @Nonnull public static String chompLast( @Nonnull String str, @Nonnull String sep )
     {
         if ( str.length() == 0 )
         {
@@ -932,7 +938,7 @@ public class StringUtils
      * @return String chomped
      * @throws NullPointerException if str or sep is <code>null</code>
      */
-    public @Nonnull static String getChomp( @Nonnull String str, @Nonnull String sep )
+    @Nonnull public static String getChomp( @Nonnull String str, @Nonnull String sep )
     {
         int idx = str.lastIndexOf( sep );
         if ( idx == str.length() - sep.length() )
@@ -958,7 +964,7 @@ public class StringUtils
      * @return String without chomped beginning
      * @throws NullPointerException if str or sep is <code>null</code>
      */
-    public @Nonnull static String prechomp( @Nonnull String str, @Nonnull String sep )
+    @Nonnull public static String prechomp( @Nonnull String str, @Nonnull String sep )
     {
         int idx = str.indexOf( sep );
         if ( idx != -1 )
@@ -980,7 +986,7 @@ public class StringUtils
      * @return String prechomped
      * @throws NullPointerException if str or sep is <code>null</code>
      */
-    public @Nonnull static String getPrechomp( @Nonnull String str, String sep )
+    @Nonnull public static String getPrechomp( @Nonnull String str, @Nonnull String sep )
     {
         int idx = str.indexOf( sep );
         if ( idx != -1 )
@@ -1006,7 +1012,7 @@ public class StringUtils
      * @return String without last character
      * @throws NullPointerException if str is <code>null</code>
      */
-    public @Nonnull static String chop( @Nonnull String str )
+    @Nonnull public static String chop( @Nonnull String str )
     {
         if ( "".equals( str ) )
         {
@@ -1037,7 +1043,7 @@ public class StringUtils
      * @return String without newline
      * @throws NullPointerException if str is <code>null</code>
      */
-    public @Nonnull static String chopNewline( @Nonnull String str )
+    @Nonnull public static String chopNewline( @Nonnull String str )
     {
         int lastIdx = str.length() - 1;
         char last = str.charAt( lastIdx );
@@ -1070,7 +1076,7 @@ public class StringUtils
      * @return String with escaped values
      * @throws NullPointerException if str is <code>null</code>
      */
-    public @Nonnull static String escape( @Nonnull String str )
+    @Nonnull public static String escape( @Nonnull String str )
     {
         // improved with code from  cybertiger@cyberiantiger.org
         // unicode from him, and defaul for < 32's.
@@ -1081,6 +1087,7 @@ public class StringUtils
             char ch = str.charAt( i );
 
             // handle unicode
+            // CHECKSTYLE_OFF: MagicNumber
             if ( ch > 0xfff )
             {
                 buffer.append( "\\u" ).append( Integer.toHexString( ch ) );
@@ -1093,6 +1100,7 @@ public class StringUtils
             {
                 buffer.append( "\\u00" ).append( Integer.toHexString( ch ) );
             }
+            // CHECKSTYLE_ON: MagicNumber
             else if ( ch < 32 )
             {
                 switch ( ch )
@@ -1167,7 +1175,7 @@ public class StringUtils
      * @throws NegativeArraySizeException if <code>repeat < 0</code>
      * @throws NullPointerException       if str is <code>null</code>
      */
-    public @Nonnull static String repeat( @Nonnull String str, int repeat )
+    @Nonnull public static String repeat( @Nonnull String str, int repeat )
     {
         StringBuilder buffer = new StringBuilder( repeat * str.length() );
         for ( int i = 0; i < repeat; i++ )
@@ -1187,7 +1195,7 @@ public class StringUtils
      * @return right padded String
      * @throws NullPointerException if str is <code>null</code>
      */
-    public @Nonnull static String rightPad( @Nonnull String str, int size )
+    @Nonnull public static String rightPad( @Nonnull String str, int size )
     {
         return rightPad( str, size, " " );
     }
@@ -1204,7 +1212,7 @@ public class StringUtils
      * @throws NullPointerException if str or delim is <code>null</code>
      * @throws ArithmeticException  if delim is the empty String
      */
-    public @Nonnull static String rightPad( @Nonnull String str, int size, @Nonnull String delim )
+    @Nonnull public static String rightPad( @Nonnull String str, int size, @Nonnull String delim )
     {
         size = ( size - str.length() ) / delim.length();
         if ( size > 0 )
@@ -1224,7 +1232,7 @@ public class StringUtils
      * @return left padded String
      * @throws NullPointerException if str or delim is <code>null</code>
      */
-    public @Nonnull static String leftPad( @Nonnull String str, int size )
+    @Nonnull public static String leftPad( @Nonnull String str, int size )
     {
         return leftPad( str, size, " " );
     }
@@ -1239,7 +1247,7 @@ public class StringUtils
      * @throws NullPointerException if str or delim is null
      * @throws ArithmeticException  if delim is the empty string
      */
-    public @Nonnull static String leftPad( @Nonnull String str, int size, @Nonnull String delim )
+    @Nonnull public static String leftPad( @Nonnull String str, int size, @Nonnull String delim )
     {
         size = ( size - str.length() ) / delim.length();
         if ( size > 0 )
@@ -1438,13 +1446,20 @@ public class StringUtils
         {
             return null;
         }
-        else if ( str.length() == 0 )
-        {
-            return "";
-        }
         else
         {
-            return String.valueOf( Character.toLowerCase( str.charAt( 0 ) ) ) + str.substring( 1 );
+            int length = str.length();
+            if ( length == 0 )
+            {
+                return "";
+            }
+            else
+            {
+                return new StringBuffer( length )
+                    .append( Character.toLowerCase( str.charAt( 0 ) ) )
+                    .append( str, 1, length )
+                    .toString();
+            }
         }
     }
 
@@ -1463,13 +1478,20 @@ public class StringUtils
         {
             return null;
         }
-        else if ( str.length() == 0 )
-        {
-            return "";
-        }
         else
         {
-            return String.valueOf( Character.toTitleCase( str.charAt( 0 ) ) ) + str.substring( 1 );
+            int length = str.length();
+            if ( length == 0 )
+            {
+                return "";
+            }
+            else
+            {
+                return new StringBuilder( length )
+                    .append( Character.toTitleCase( str.charAt( 0 ) ) )
+                    .append( str, 1, length )
+                    .toString();
+            }
         }
     }
 
@@ -1865,7 +1887,7 @@ public class StringUtils
      * @return the passed in Object's toString, or blank if it was
      *         <code>null</code>
      */
-    public @Nonnull static String defaultString( Object obj )
+    @Nonnull public static String defaultString( Object obj )
     {
         return defaultString( obj, "" );
     }
@@ -1881,7 +1903,7 @@ public class StringUtils
      * @return the passed in string, or the default if it was
      *         <code>null</code>
      */
-    public @Nonnull static String defaultString( Object obj, @Nonnull String defaultString )
+    @Nonnull public static String defaultString( Object obj, @Nonnull String defaultString )
     {
         return ( obj == null ) ? defaultString : obj.toString();
     }
@@ -1917,7 +1939,7 @@ public class StringUtils
      * @param delimiter the delimiter to use
      * @return the reversed String
      */
-    public @Nonnull static String reverseDelimitedString( @Nonnull String str, String delimiter )
+    @Nonnull public static String reverseDelimitedString( @Nonnull String str, String delimiter )
     {
         // could implement manually, but simple way is to reuse other,
         // probably slower, methods.
@@ -1964,7 +1986,7 @@ public class StringUtils
      *
      * @param maxWidth maximum length of result string
      */
-    public @Nonnull static String abbreviate( @Nonnull String s, int maxWidth )
+    @Nonnull public static String abbreviate( @Nonnull String s, int maxWidth )
     {
         return abbreviate( s, 0, maxWidth );
     }
@@ -1981,7 +2003,7 @@ public class StringUtils
      * @param offset   left edge of source string
      * @param maxWidth maximum length of result string
      */
-    public @Nonnull static String abbreviate( @Nonnull String s, int offset, int maxWidth )
+    @Nonnull public static String abbreviate( @Nonnull String s, int offset, int maxWidth )
     {
         if ( maxWidth < 4 )
         {
@@ -2108,7 +2130,7 @@ public class StringUtils
      * @param replaceThis
      * @return humped String
      */
-    public @Nonnull static String removeAndHump( @Nonnull String data, @Nonnull String replaceThis )
+    @Nonnull public static String removeAndHump( @Nonnull String data, @Nonnull String replaceThis )
     {
         String temp;
 
@@ -2141,13 +2163,18 @@ public class StringUtils
      * @return data string with the first character transformed to uppercase
      * @throws NullPointerException if data is <code>null</code>
      */
-    public @Nonnull static String capitalizeFirstLetter( @Nonnull String data )
+    @Nonnull public static String capitalizeFirstLetter( @Nonnull String data )
     {
-        char firstLetter = Character.toTitleCase( data.substring( 0, 1 ).charAt( 0 ) );
-
-        String restLetters = data.substring( 1 );
-
-        return firstLetter + restLetters;
+        char firstChar = data.charAt( 0 );
+        char titleCase = Character.toTitleCase( firstChar );
+        if ( firstChar == titleCase )
+        {
+            return data;
+        }
+        StringBuilder result = new StringBuilder( data.length() );
+        result.append( titleCase );
+        result.append(  data, 1, data.length() );
+        return result.toString();
     }
 
     /**
@@ -2163,7 +2190,7 @@ public class StringUtils
      * @return data string with the first character transformed to lowercase
      * @throws NullPointerException if data is <code>null</code>
      */
-    public @Nonnull static String lowercaseFirstLetter( @Nonnull String data )
+    @Nonnull public static String lowercaseFirstLetter( @Nonnull String data )
     {
         char firstLetter = Character.toLowerCase( data.substring( 0, 1 ).charAt( 0 ) );
 
@@ -2180,7 +2207,7 @@ public class StringUtils
      * @param view
      * @return deHumped String
      */
-    public @Nonnull static String addAndDeHump( @Nonnull String view )
+    @Nonnull public static String addAndDeHump( @Nonnull String view )
     {
         StringBuilder sb = new StringBuilder();
 
@@ -2245,8 +2272,8 @@ public class StringUtils
      * @see #quoteAndEscape(String, char, char[], char[], char, boolean)
      * 
      */
-    public static String quoteAndEscape( @Nullable String source, char quoteChar, @Nonnull final char[] escapedChars, char escapeChar,
-                                         boolean force )
+    public static String quoteAndEscape( @Nullable String source, char quoteChar,
+                                         @Nonnull final char[] escapedChars, char escapeChar, boolean force )
     {
         return quoteAndEscape( source, quoteChar, escapedChars, new char[]{ ' ' }, escapeChar, force );
     }
@@ -2349,7 +2376,7 @@ public class StringUtils
      * @return a string with unique whitespace.
      * 
      */
-    public @Nonnull static String removeDuplicateWhitespace( @Nonnull String s )
+    @Nonnull public static String removeDuplicateWhitespace( @Nonnull String s )
     {
         StringBuilder result = new StringBuilder();
         int length = s.length();
@@ -2479,10 +2506,45 @@ public class StringUtils
      * @param searchStr the String to find, may be null
      * @return true if the String contains the search String,
      *         false if not or <code>null</code> string input
-     * 
      */
     public static boolean contains( @Nullable String str, @Nullable String searchStr )
     {
         return !( str == null || searchStr == null ) && str.contains( searchStr );
     }
+
+    /**
+     * <p>Checks if String ends with a search String, handling <code>null</code>.</p>
+     * <p/>
+     * <p>A <code>null</code> String will return <code>false</code>.</p>
+     * <p/>
+     * <pre>
+     * StringUtils.endsWithIgnoreCase(null, *)     = false
+     * StringUtils.endsWithIgnoreCase(*, null)     = false
+     * StringUtils.endsWithIgnoreCase("", "")      = true
+     * StringUtils.endsWithIgnoreCase("abc", "")   = true
+     * StringUtils.endsWithIgnoreCase("abc", "C")  = true
+     * StringUtils.endsWithIgnoreCase("abc", "a")  = false
+     * </pre>
+     *
+     * @param str       the String to check, may be null
+     * @param searchStr the String to find at end, may be null
+     * @return true if the String ends with the search String,
+     *         false if not or <code>null</code> string input
+     * 
+     */
+    public static boolean endsWithIgnoreCase( @Nullable String str, @Nullable String searchStr )
+    {
+        if ( str == null || searchStr == null )
+        {
+            // for consistency with contains
+            return false;
+        }
+
+        if ( str.length() < searchStr.length() )
+        {
+            return false;
+        }
+
+        return str.regionMatches( true, str.length() - searchStr.length(), searchStr, 0, searchStr.length() );
+    }
 }
