@@ -22,13 +22,13 @@ package org.apache.maven.shared.utils.cli;
 import java.util.concurrent.Callable;
 
 /**
- * Callable wrapper that exposes the proper exeception type to the client.
+ * Callable wrapper that exposes the proper exception type to the client.
  *
  * @author Kristian Rosenvold
  */
 public interface CommandLineCallable
     extends Callable<Integer>
 {
-    public Integer call()
+    Integer call()
         throws CommandLineException;
 }
