@@ -19,10 +19,8 @@ package org.apache.maven.shared.utils.cli;
  * under the License.
  */
 
-import org.apache.maven.shared.utils.Os;
-import org.apache.maven.shared.utils.StringUtils;
-
 import java.io.InputStream;
+import java.nio.charset.Charset;
 import java.util.ArrayList;
 import java.util.List;
 import java.util.Locale;
@@ -30,17 +28,22 @@ import java.util.Map;
 import java.util.Properties;
 import java.util.StringTokenizer;
 
+import javax.annotation.Nonnull;
+import javax.annotation.Nullable;
+
 import org.apache.maven.shared.utils.Os;
 import org.apache.maven.shared.utils.StringUtils;
 
 /**
  * @author <a href="mailto:trygvis@inamo.no">Trygve Laugst&oslash;l </a>
- * @version $Id: CommandLineUtils.java 1449899 2013-02-25 21:05:20Z krosenvold $
+ * @version $Id: CommandLineUtils.java 1670518 2015-03-31 23:38:42Z hboutemy $
  */
 public abstract class CommandLineUtils
 {
 
-
+    /**
+     * 
+     */
     @SuppressWarnings( "UnusedDeclaration" )
     public static class StringStreamConsumer
         implements StreamConsumer
@@ -80,14 +83,14 @@ public abstract class CommandLineUtils
 
 
     @SuppressWarnings( "UnusedDeclaration" )
-    public static int executeCommandLine( Commandline cl, StreamConsumer systemOut, StreamConsumer systemErr )
+    public static int executeCommandLine( @Nonnull Commandline cl, StreamConsumer systemOut, StreamConsumer systemErr )
         throws CommandLineException
     {
         return executeCommandLine( cl, null, systemOut, systemErr, 0 );
     }
 
     @SuppressWarnings( "UnusedDeclaration" )
-    public static int executeCommandLine( Commandline cl, StreamConsumer systemOut, StreamConsumer systemErr,
+    public static int executeCommandLine( @Nonnull Commandline cl, StreamConsumer systemOut, StreamConsumer systemErr,
                                           int timeoutInSeconds )
         throws CommandLineException
     {
@@ -95,7 +98,7 @@ public abstract class CommandLineUtils
     }
 
     @SuppressWarnings( "UnusedDeclaration" )
-    public static int executeCommandLine( Commandline cl, InputStream systemIn, StreamConsumer systemOut,
+    public static int executeCommandLine( @Nonnull Commandline cl, InputStream systemIn, StreamConsumer systemOut,
                                           StreamConsumer systemErr )
         throws CommandLineException
     {
@@ -112,7 +115,7 @@ public abstract class CommandLineUtils
      * @throws CommandLineException or CommandLineTimeOutException if time out occurs
      * @noinspection ThrowableResultOfMethodCallIgnored
      */
-    public static int executeCommandLine( Commandline cl, InputStream systemIn, StreamConsumer systemOut,
+    public static int executeCommandLine( @Nonnull Commandline cl, InputStream systemIn, StreamConsumer systemOut,
                                           StreamConsumer systemErr, int timeoutInSeconds )
         throws CommandLineException
     {
@@ -131,13 +134,37 @@ public abstract class CommandLineUtils
      * @throws CommandLineException or CommandLineTimeOutException if time out occurs
      * @noinspection ThrowableResultOfMethodCallIgnored
      */
-    public static int executeCommandLine( Commandline cl, InputStream systemIn, StreamConsumer systemOut,
+    public static int executeCommandLine( @Nonnull Commandline cl, InputStream systemIn, StreamConsumer systemOut,
                                           StreamConsumer systemErr, int timeoutInSeconds,
-                                          Runnable runAfterProcessTermination )
+                                          @Nullable Runnable runAfterProcessTermination )
+        throws CommandLineException
+    {
+        return executeCommandLine( cl, systemIn, systemOut, systemErr, timeoutInSeconds, runAfterProcessTermination,
+                                   null );
+    }
+
+    /**
+     * @param cl               The command line to execute
+     * @param systemIn         The input to read from, must be thread safe
+     * @param systemOut        A consumer that receives output, must be thread safe
+     * @param systemErr        A consumer that receives system error stream output, must be thread safe
+     * @param timeoutInSeconds Positive integer to specify timeout, zero and negative integers for no timeout.
+     * @param runAfterProcessTermination Optional callback to run after the process terminated or the the timeout was
+     *  exceeded, but before waiting on the stream feeder and pumpers to finish.
+     * @param streamCharset    Charset to use for reading streams
+     * @return A return value, see {@link Process#exitValue()}
+     * @throws CommandLineException or CommandLineTimeOutException if time out occurs
+     * @noinspection ThrowableResultOfMethodCallIgnored
+     */
+    public static int executeCommandLine( @Nonnull Commandline cl, InputStream systemIn, StreamConsumer systemOut,
+                                          StreamConsumer systemErr, int timeoutInSeconds,
+                                          @Nullable Runnable runAfterProcessTermination,
+                                          @Nullable final Charset streamCharset )
         throws CommandLineException
     {
         final CommandLineCallable future =
-            executeCommandLineAsCallable( cl, systemIn, systemOut, systemErr, timeoutInSeconds, runAfterProcessTermination );
+            executeCommandLineAsCallable( cl, systemIn, systemOut, systemErr, timeoutInSeconds,
+                                          runAfterProcessTermination, streamCharset );
         return future.call();
     }
 
@@ -150,19 +177,50 @@ public abstract class CommandLineUtils
      * @param systemErr        A consumer that receives system error stream output, must be thread safe
      * @param timeoutInSeconds Positive integer to specify timeout, zero and negative integers for no timeout.
      * @param runAfterProcessTermination Optional callback to run after the process terminated or the the timeout was
-     * @return A CommandLineCallable that provides the process return value, see {@link Process#exitValue()}. "call" must be called on
-     *         this to be sure the forked process has terminated, no guarantees is made about
+     * @return A CommandLineCallable that provides the process return value, see {@link Process#exitValue()}. "call"
+     *         must be called on this to be sure the forked process has terminated, no guarantees is made about
      *         any internal state before after the completion of the call statements
      * @throws CommandLineException or CommandLineTimeOutException if time out occurs
      * @noinspection ThrowableResultOfMethodCallIgnored
      */
-    private static CommandLineCallable executeCommandLineAsCallable( final Commandline cl, final InputStream systemIn,
+    public static CommandLineCallable executeCommandLineAsCallable( @Nonnull final Commandline cl,
+                                                                    @Nullable final InputStream systemIn,
                                                                     final StreamConsumer systemOut,
                                                                     final StreamConsumer systemErr,
                                                                     final int timeoutInSeconds,
-                                                                    final Runnable runAfterProcessTermination )
+                                                                  @Nullable final Runnable runAfterProcessTermination )
         throws CommandLineException
     {
+        return executeCommandLineAsCallable( cl, systemIn, systemOut, systemErr, timeoutInSeconds,
+                                             runAfterProcessTermination, null );
+    }
+
+    /**
+     * Immediately forks a process, returns a callable that will block until process is complete.
+     *
+     * @param cl               The command line to execute
+     * @param systemIn         The input to read from, must be thread safe
+     * @param systemOut        A consumer that receives output, must be thread safe
+     * @param systemErr        A consumer that receives system error stream output, must be thread safe
+     * @param timeoutInSeconds Positive integer to specify timeout, zero and negative integers for no timeout.
+     * @param runAfterProcessTermination Optional callback to run after the process terminated or the the timeout was
+     * @param streamCharset    Charset to use for reading streams
+     * @return A CommandLineCallable that provides the process return value, see {@link Process#exitValue()}. "call"
+     *         must be called on this to be sure the forked process has terminated, no guarantees is made about
+     *         any internal state before after the completion of the call statements
+     * @throws CommandLineException or CommandLineTimeOutException if time out occurs
+     * @noinspection ThrowableResultOfMethodCallIgnored
+     */
+    public static CommandLineCallable executeCommandLineAsCallable( @Nonnull final Commandline cl,
+                                                                    @Nullable final InputStream systemIn,
+                                                                    final StreamConsumer systemOut,
+                                                                    final StreamConsumer systemErr,
+                                                                    final int timeoutInSeconds,
+                                                                    @Nullable final Runnable runAfterProcessTermination,
+                                                                    @Nullable final Charset streamCharset )
+        throws CommandLineException
+    {
+        //noinspection ConstantConditions
         if ( cl == null )
         {
             throw new IllegalArgumentException( "cl cannot be null." );
@@ -269,7 +327,7 @@ public abstract class CommandLineUtils
         };
     }
 
-    private static void waitForAllPumpers( StreamFeeder inputFeeder, StreamPumper outputPumper,
+    private static void waitForAllPumpers( @Nullable StreamFeeder inputFeeder, StreamPumper outputPumper,
                                            StreamPumper errorPumper )
         throws InterruptedException
     {
