@@ -407,7 +407,8 @@ public class DirectoryScanner
                 {
                     scanAction = scanConductor.visitDirectory( "", basedir );
 
-                    if ( ScanConductor.ScanAction.ABORT.equals( scanAction ) || ScanConductor.ScanAction.ABORT_DIRECTORY.equals( scanAction )
+                    if ( ScanConductor.ScanAction.ABORT.equals( scanAction )
+                        || ScanConductor.ScanAction.ABORT_DIRECTORY.equals( scanAction )
                         || ScanConductor.ScanAction.NO_RECURSE.equals( scanAction ) )
                     {
                         return;
@@ -631,7 +632,8 @@ public class DirectoryScanner
                         {
                             scanAction = scanConductor.visitDirectory( name, file );
 
-                            if ( ScanConductor.ScanAction.ABORT.equals( scanAction ) || ScanConductor.ScanAction.ABORT_DIRECTORY.equals( scanAction ) )
+                            if ( ScanConductor.ScanAction.ABORT.equals( scanAction )
+                                || ScanConductor.ScanAction.ABORT_DIRECTORY.equals( scanAction ) )
                             {
                                 return;
                             }
@@ -777,7 +779,7 @@ public class DirectoryScanner
      * patterns. The names are relative to the base directory.
      *
      * @return the names of the files which matched at least one of the include patterns and none of the exclude
-     *         patterns.
+     *         patterns. May also contain symbolic links to files.
      */
     public String[] getIncludedFiles()
     {
@@ -821,7 +823,7 @@ public class DirectoryScanner
      * patterns. The names are relative to the base directory.
      *
      * @return the names of the directories which matched at least one of the include patterns and none of the exclude
-     *         patterns.
+     *         patterns. May also contain symbolic links to directories.
      */
     public String[] getIncludedDirectories()
     {
@@ -890,7 +892,7 @@ public class DirectoryScanner
     boolean isSymbolicLink( final File parent, final String name )
         throws IOException
     {
-        if ( Java7Support.isJava7())
+        if ( Java7Support.isAtLeastJava7() )
         {
             return Java7Support.isSymLink( parent );
         }
