@@ -19,6 +19,12 @@ package org.apache.maven.shared.utils.io;
  * under the License.
  */
 
+import org.apache.maven.shared.utils.Os;
+import org.apache.maven.shared.utils.StringUtils;
+
+import javax.annotation.Nonnull;
+import javax.annotation.Nullable;
+import javax.annotation.WillClose;
 import java.io.BufferedReader;
 import java.io.File;
 import java.io.FileInputStream;
@@ -42,13 +48,6 @@ import java.util.Collections;
 import java.util.List;
 import java.util.Random;
 
-import org.apache.maven.shared.utils.Os;
-import org.apache.maven.shared.utils.StringUtils;
-
-import javax.annotation.Nonnull;
-import javax.annotation.Nullable;
-import javax.annotation.WillClose;
-
 /**
  * This class provides basic facilities for manipulating files and file paths.
  * <p/>
@@ -84,7 +83,7 @@ import javax.annotation.WillClose;
  * @author <a href="mailto:Christoph.Reck@dlr.de">Christoph.Reck</a>
  * @author <a href="mailto:peter@apache.org">Peter Donald</a>
  * @author <a href="mailto:jefft@apache.org">Jeff Turner</a>
- * @version $Id: FileUtils.java 1401850 2012-10-24 19:59:48Z rfscholte $
+ * @version $Id: FileUtils.java 1670518 2015-03-31 23:38:42Z hboutemy $
  */
 public class FileUtils
 {
@@ -122,7 +121,7 @@ public class FileUtils
      * Non-valid Characters for naming files, folders under Windows: <code>":", "*", "?", "\"", "<", ">", "|"</code>
      *
      * @see <a href="http://support.microsoft.com/?scid=kb%3Ben-us%3B177506&x=12&y=13">
-     *      http://support.microsoft.com/?scid=kb%3Ben-us%3B177506&x=12&y=13</a>
+     * http://support.microsoft.com/?scid=kb%3Ben-us%3B177506&x=12&y=13</a>
      */
     private static final String[] INVALID_CHARACTERS_FOR_WINDOWS_FILE_NAME = { ":", "*", "?", "\"", "<", ">", "|" };
 
@@ -130,7 +129,7 @@ public class FileUtils
      * @return the default excludes pattern
      * @see DirectoryScanner#DEFAULTEXCLUDES
      */
-    public @Nonnull static String[] getDefaultExcludes()
+    @Nonnull public static String[] getDefaultExcludes()
     {
         return DirectoryScanner.DEFAULTEXCLUDES;
     }
@@ -139,7 +138,7 @@ public class FileUtils
      * @return the default excludes pattern as list.
      * @see #getDefaultExcludes()
      */
-    @Nonnull public static List<String>  getDefaultExcludesAsList()
+    @Nonnull public static List<String> getDefaultExcludesAsList()
     {
         return Arrays.asList( getDefaultExcludes() );
     }
@@ -149,7 +148,7 @@ public class FileUtils
      * @see DirectoryScanner#DEFAULTEXCLUDES
      * @see StringUtils#join(Object[], String)
      */
-    public @Nonnull static String getDefaultExcludesAsString()
+    @Nonnull public static String getDefaultExcludesAsString()
     {
         return StringUtils.join( DirectoryScanner.DEFAULTEXCLUDES, "," );
     }
@@ -161,7 +160,7 @@ public class FileUtils
      * @param filename the file path
      * @return The directory portion excluding the ending file separator.
      */
-    public @Nonnull static String dirname( @Nonnull String filename )
+    @Nonnull public static String dirname( @Nonnull String filename )
     {
         int i = filename.lastIndexOf( File.separator );
         return ( i >= 0 ? filename.substring( 0, i ) : "" );
@@ -173,7 +172,7 @@ public class FileUtils
      * @param filename the file path
      * @return The filename string with extension.
      */
-    public @Nonnull static String filename( @Nonnull String filename )
+    @Nonnull public static String filename( @Nonnull String filename )
     {
         int i = filename.lastIndexOf( File.separator );
         return ( i >= 0 ? filename.substring( i + 1 ) : filename );
@@ -187,7 +186,7 @@ public class FileUtils
      * @param filename the file path
      * @return the extension of the file
      */
-    public @Nonnull static String extension( @Nonnull String filename )
+    @Nonnull public static String extension( @Nonnull String filename )
     {
         // Ensure the last dot is after the last file separator
         int lastSep = filename.lastIndexOf( File.separatorChar );
@@ -232,7 +231,7 @@ public class FileUtils
      * @return the file content using the platform encoding.
      * @throws IOException if any
      */
-    public @Nonnull static String fileRead( @Nonnull String file )
+    @Nonnull public static String fileRead( @Nonnull String file )
         throws IOException
     {
         return fileRead( file, null );
@@ -244,7 +243,7 @@ public class FileUtils
      * @return the file content using the specified encoding.
      * @throws IOException if any
      */
-    private @Nonnull static String fileRead( @Nonnull String file, @Nullable String encoding )
+    @Nonnull private static String fileRead( @Nonnull String file, @Nullable String encoding )
         throws IOException
     {
         return fileRead( new File( file ), encoding );
@@ -257,7 +256,7 @@ public class FileUtils
      * @return the file content using the platform encoding.
      * @throws IOException if any
      */
-    public @Nonnull static String fileRead( @Nonnull File file )
+    @Nonnull public static String fileRead( @Nonnull File file )
         throws IOException
     {
         return fileRead( file, null );
@@ -269,7 +268,7 @@ public class FileUtils
      * @return the file content using the specified encoding.
      * @throws IOException if any
      */
-    public @Nonnull static String fileRead( @Nonnull File file, @Nullable String encoding )
+    @Nonnull public static String fileRead( @Nonnull File file, @Nullable String encoding )
         throws IOException
     {
         StringBuilder buf = new StringBuilder();
@@ -304,10 +303,10 @@ public class FileUtils
     /**
      * @param file the file path
      * @return the file content lines as String[] using the systems default encoding.
-     *         An empty List if the file didn't exist.
+     * An empty List if the file didn't exist.
      * @throws IOException
      */
-    public @Nonnull static String[] fileReadArray( @Nonnull File file )
+    @Nonnull public static String[] fileReadArray( @Nonnull File file )
         throws IOException
     {
         List<String> files = loadFile( file );
@@ -395,7 +394,6 @@ public class FileUtils
      * @param encoding The encoding of the file.
      * @param data     The content to write to the file.
      * @throws IOException if any
-     * 
      */
     public static void fileWrite( @Nonnull File file, @Nullable String encoding, @Nonnull String data )
         throws IOException
@@ -427,7 +425,6 @@ public class FileUtils
      * @param file The path of the file to write.
      * @param data The content to write to the file.
      * @throws IOException if any
-     * 
      */
     public static void fileWriteArray( @Nonnull File file, @Nullable String... data )
         throws IOException
@@ -442,7 +439,6 @@ public class FileUtils
      * @param encoding The encoding of the file.
      * @param data     The content to write to the file.
      * @throws IOException if any
-     * 
      */
     public static void fileWriteArray( @Nonnull File file, @Nullable String encoding, @Nullable String... data )
         throws IOException
@@ -484,7 +480,7 @@ public class FileUtils
     {
         File file = new File( fileName );
         //noinspection ResultOfMethodCallIgnored
-        file.delete();
+        deleteLegacyStyle( file );
     }
 
     /**
@@ -553,7 +549,7 @@ public class FileUtils
     /**
      * Private helper method for getFilesFromExtension()
      */
-    private @Nonnull static List<String> blendFilesToList( @Nonnull List<String> v, @Nonnull String...files )
+    @Nonnull private static List<String> blendFilesToList( @Nonnull List<String> v, @Nonnull String... files )
     {
         Collections.addAll( v, files );
 
@@ -597,9 +593,9 @@ public class FileUtils
 
         if ( Os.isFamily( Os.FAMILY_WINDOWS ) && !isValidWindowsFileName( file ) )
         {
-            throw new IllegalArgumentException( "The file (" + dir
-                + ") cannot contain any of the following characters: \n"
-                + StringUtils.join( INVALID_CHARACTERS_FOR_WINDOWS_FILE_NAME, " " ) );
+            throw new IllegalArgumentException(
+                "The file (" + dir + ") cannot contain any of the following characters: \n" + StringUtils.join(
+                    INVALID_CHARACTERS_FOR_WINDOWS_FILE_NAME, " " ) );
         }
 
         if ( !file.exists() )
@@ -659,7 +655,7 @@ public class FileUtils
      *
      * @param url File URL.
      * @return The equivalent <code>File</code> object, or <code>null</code> if the URL's protocol
-     *         is not <code>file</code>
+     * is not <code>file</code>
      */
     public @Nullable static File toFile( final @Nullable URL url )
     {
@@ -689,7 +685,7 @@ public class FileUtils
      * @return the array of URLs
      * @throws IOException if an error occurs
      */
-    public @Nonnull static URL[] toURLs( @Nonnull final File... files )
+    @Nonnull public static URL[] toURLs( @Nonnull final File... files )
         throws IOException
     {
         final URL[] urls = new URL[files.length];
@@ -716,7 +712,7 @@ public class FileUtils
      * @param filename the path of the file
      * @return the filename minus extension
      */
-    public @Nonnull static String removeExtension( @Nonnull final String filename )
+    @Nonnull public static String removeExtension( @Nonnull final String filename )
     {
         String ext = extension( filename );
 
@@ -741,7 +737,7 @@ public class FileUtils
      * @param filename the path of the file
      * @return the extension of filename or "" if none
      */
-    public @Nonnull static String getExtension( @Nonnull final String filename )
+    @Nonnull public static String getExtension( @Nonnull final String filename )
     {
         return extension( filename );
     }
@@ -756,7 +752,8 @@ public class FileUtils
      * @throws java.io.FileNotFoundException if <code>source</code> isn't a normal file.
      * @throws IllegalArgumentException      if <code>destinationDirectory</code> isn't a directory.
      * @throws IOException                   if <code>source</code> does not exist, the file in
-     *                                       <code>destinationDirectory</code> cannot be written to, or an IO error occurs during copying.
+     *                                       <code>destinationDirectory</code> cannot be written to, or an IO error
+     *                                       occurs during copying.
      */
     public static void copyFileToDirectory( @Nonnull final File source, @Nonnull final File destinationDirectory )
         throws IOException
@@ -780,9 +777,11 @@ public class FileUtils
      * @throws java.io.FileNotFoundException if <code>source</code> isn't a normal file.
      * @throws IllegalArgumentException      if <code>destinationDirectory</code> isn't a directory.
      * @throws IOException                   if <code>source</code> does not exist, the file in
-     *                                       <code>destinationDirectory</code> cannot be written to, or an IO error occurs during copying.
+     *                                       <code>destinationDirectory</code> cannot be written to, or an IO error
+     *                                       occurs during copying.
      */
-    private static void copyFileToDirectoryIfModified( @Nonnull final File source, @Nonnull final File destinationDirectory )
+    private static void copyFileToDirectoryIfModified( @Nonnull final File source,
+                                                       @Nonnull final File destinationDirectory )
         throws IOException
     {
         if ( destinationDirectory.exists() && !destinationDirectory.isDirectory() )
@@ -805,7 +804,6 @@ public class FileUtils
      * @throws IOException                   if <code>source</code> does not exist, <code>destination</code> cannot be
      *                                       written to, or an IO error occurs during copying.
      * @throws java.io.FileNotFoundException if <code>destination</code> is a directory
-     *
      */
     public static void copyFile( @Nonnull final File source, @Nonnull final File destination )
         throws IOException
@@ -816,6 +814,12 @@ public class FileUtils
             final String message = "File " + source + " does not exist";
             throw new IOException( message );
         }
+        if ( Java7Support.isAtLeastJava7() && Java7Support.isSymLink( source ) )
+        {
+            File target = Java7Support.readSymbolicLink( source );
+            Java7Support.createSymbolicLink( destination, target );
+            return;
+        }
 
         //check source != destination, see PLXUTILS-10
         if ( source.getCanonicalPath().equals( destination.getCanonicalPath() ) )
@@ -938,7 +942,8 @@ public class FileUtils
      *                     <li>an IO error occurs during copying</li>
      *                     </ul>
      */
-    private static void copyStreamToFile( @Nonnull final @WillClose InputStream source, @Nonnull final File destination )
+    private static void copyStreamToFile( @Nonnull final @WillClose InputStream source,
+                                          @Nonnull final File destination )
         throws IOException
     {
         FileOutputStream output = null;
@@ -986,7 +991,7 @@ public class FileUtils
      * @param path the path to normalize
      * @return the normalized String, or <code>null</code> if too many ..'s.
      */
-    public static String normalize( final String path )
+    public static @Nonnull String normalize( @Nonnull final String path )
     {
         String normalized = path;
         // Resolve occurrences of "//" in the normalized path
@@ -1041,7 +1046,7 @@ public class FileUtils
      * @param filename Absolute or relative file path to resolve.
      * @return The canonical <code>File</code> of <code>filename</code>.
      */
-    public static File resolveFile( final File baseFile, String filename )
+    public static @Nonnull File resolveFile( final File baseFile, @Nonnull String filename )
     {
         String filenm = filename;
         if ( '/' != File.separatorChar )
@@ -1118,7 +1123,7 @@ public class FileUtils
      * @param file the file path
      * @throws IOException if any
      */
-    public static void forceDelete( final String file )
+    public static void forceDelete( @Nonnull final String file )
         throws IOException
     {
         forceDelete( new File( file ) );
@@ -1152,6 +1157,50 @@ public class FileUtils
         }
     }
 
+    /**
+     * deletes a file.
+     *
+     * @param file The file to delete
+     * @throws IOException If the file cannot be delted.
+     */
+
+
+    public static void delete( @Nonnull File file )
+        throws IOException
+    {
+        if ( Java7Support.isAtLeastJava7() )
+        {
+            Java7Support.delete( file );
+        }
+        else
+        {
+            if ( !file.delete() )
+            {
+                throw new IOException( "Could not delete " + file.getName() );
+            }
+        }
+    }
+
+    public static boolean deleteLegacyStyle( @Nonnull File file )
+    {
+        if ( Java7Support.isAtLeastJava7() )
+        {
+            try
+            {
+                Java7Support.delete( file );
+                return true;
+            }
+            catch ( IOException e )
+            {
+                return false;
+            }
+        }
+        else
+        {
+            return file.delete();
+        }
+    }
+
     /**
      * Accommodate Windows bug encountered in both Sun and IBM JDKs.
      * Others possible. If the delete does not work, call System.gc(),
@@ -1168,7 +1217,7 @@ public class FileUtils
             throw new IOException( "File " + file + " isn't a file." );
         }
 
-        if ( !file.delete() )
+        if ( !deleteLegacyStyle( file ) )
         {
             if ( Os.isFamily( Os.FAMILY_WINDOWS ) )
             {
@@ -1179,11 +1228,11 @@ public class FileUtils
             try
             {
                 Thread.sleep( 10 );
-                return file.delete();
+                return deleteLegacyStyle( file );
             }
             catch ( InterruptedException ex )
             {
-                return file.delete();
+                return deleteLegacyStyle( file );
             }
         }
 
@@ -1258,13 +1307,13 @@ public class FileUtils
         /* try delete the directory before its contents, which will take
          * care of any directories that are really symbolic links.
          */
-        if ( directory.delete() )
+        if ( deleteLegacyStyle( directory ) )
         {
             return;
         }
 
         cleanDirectory( directory );
-        if ( !directory.delete() )
+        if ( !deleteLegacyStyle( directory ) )
         {
             final String message = "Directory " + directory + " unable to be deleted.";
             throw new IOException( message );
@@ -1384,7 +1433,8 @@ public class FileUtils
      * @throws IOException
      * @see #getFileNames(File, String, String, boolean)
      */
-    public @Nonnull static List<File> getFiles( @Nonnull File directory, @Nullable String includes, @Nullable String excludes )
+    @Nonnull
+    public static List<File> getFiles( @Nonnull File directory, @Nullable String includes, @Nullable String excludes )
         throws IOException
     {
         return getFiles( directory, includes, excludes, true );
@@ -1401,7 +1451,9 @@ public class FileUtils
      * @throws IOException
      * @see #getFileNames(File, String, String, boolean)
      */
-    public @Nonnull static List<File> getFiles( @Nonnull File directory, @Nullable String includes, @Nullable  String excludes, boolean includeBasedir )
+    @Nonnull
+    public static List<File> getFiles( @Nonnull File directory, @Nullable String includes, @Nullable String excludes,
+                                       boolean includeBasedir )
         throws IOException
     {
         List<String> fileNames = getFileNames( directory, includes, excludes, includeBasedir );
@@ -1427,7 +1479,8 @@ public class FileUtils
      * @return a list of files as String
      * @throws IOException
      */
-    public @Nonnull static List<String> getFileNames( @Nonnull File directory, @Nullable String includes, @Nullable  String excludes, boolean includeBasedir )
+    @Nonnull public static List<String> getFileNames( @Nonnull File directory, @Nullable String includes,
+                                                      @Nullable String excludes, boolean includeBasedir )
         throws IOException
     {
         return getFileNames( directory, includes, excludes, includeBasedir, true );
@@ -1444,8 +1497,9 @@ public class FileUtils
      * @return a list of files as String
      * @throws IOException
      */
-    private @Nonnull static List<String> getFileNames( @Nonnull File directory, @Nullable String includes, @Nullable  String excludes, boolean includeBasedir,
-                                             boolean isCaseSensitive )
+    @Nonnull private static List<String> getFileNames( @Nonnull File directory, @Nullable String includes,
+                                                       @Nullable String excludes, boolean includeBasedir,
+                                                       boolean isCaseSensitive )
         throws IOException
     {
         return getFileAndDirectoryNames( directory, includes, excludes, includeBasedir, isCaseSensitive, true, false );
@@ -1462,8 +1516,8 @@ public class FileUtils
      * @return a list of directories as String
      * @throws IOException
      */
-    public @Nonnull static List<String> getDirectoryNames( @Nonnull File directory, @Nullable String includes, @Nullable String excludes,
-                                                  boolean includeBasedir )
+    @Nonnull public static List<String> getDirectoryNames( @Nonnull File directory, @Nullable String includes,
+                                                           @Nullable String excludes, boolean includeBasedir )
         throws IOException
     {
         return getDirectoryNames( directory, includes, excludes, includeBasedir, true );
@@ -1480,8 +1534,9 @@ public class FileUtils
      * @return a list of directories as String
      * @throws IOException
      */
-    public @Nonnull static List<String> getDirectoryNames( @Nonnull File directory, @Nullable String includes, @Nullable String excludes,
-                                                  boolean includeBasedir, boolean isCaseSensitive )
+    @Nonnull public static List<String> getDirectoryNames( @Nonnull File directory, @Nullable String includes,
+                                                           @Nullable String excludes, boolean includeBasedir,
+                                                           boolean isCaseSensitive )
         throws IOException
     {
         return getFileAndDirectoryNames( directory, includes, excludes, includeBasedir, isCaseSensitive, false, true );
@@ -1499,9 +1554,10 @@ public class FileUtils
      * @param getDirectories  true if get directories
      * @return a list of files as String
      */
-    public @Nonnull static List<String> getFileAndDirectoryNames( File directory, @Nullable String includes, @Nullable String excludes,
-                                                         boolean includeBasedir, boolean isCaseSensitive,
-                                                         boolean getFiles, boolean getDirectories )
+    @Nonnull public static List<String> getFileAndDirectoryNames( File directory, @Nullable String includes,
+                                                                  @Nullable String excludes, boolean includeBasedir,
+                                                                  boolean isCaseSensitive, boolean getFiles,
+                                                                  boolean getDirectories )
     {
         DirectoryScanner scanner = new DirectoryScanner();
 
@@ -1567,7 +1623,7 @@ public class FileUtils
      * @param destinationDirectory the target dir
      * @throws IOException if any
      */
-    public static void copyDirectory( File sourceDirectory, File destinationDirectory )
+    public static void copyDirectory( @Nonnull File sourceDirectory, @Nonnull File destinationDirectory )
         throws IOException
     {
         copyDirectory( sourceDirectory, destinationDirectory, "**", null );
@@ -1583,8 +1639,8 @@ public class FileUtils
      * @throws IOException if any
      * @see #getFiles(File, String, String)
      */
-    public static void copyDirectory( @Nonnull File sourceDirectory, @Nonnull File destinationDirectory, @Nullable String includes,
-                                      @Nullable  String excludes )
+    public static void copyDirectory( @Nonnull File sourceDirectory, @Nonnull File destinationDirectory,
+                                      @Nullable String includes, @Nullable String excludes )
         throws IOException
     {
         if ( !sourceDirectory.exists() )
@@ -1685,8 +1741,8 @@ public class FileUtils
             {
                 if ( !destination.exists() && !destination.mkdirs() )
                 {
-                    throw new IOException( "Could not create destination directory '" + destination.getAbsolutePath()
-                        + "'." );
+                    throw new IOException(
+                        "Could not create destination directory '" + destination.getAbsolutePath() + "'." );
                 }
 
                 copyDirectoryStructure( file, destination, rootDestinationDirectory, onlyModifiedFiles );
@@ -1714,7 +1770,7 @@ public class FileUtils
     public static void rename( @Nonnull File from, @Nonnull File to )
         throws IOException
     {
-        if ( to.exists() && !to.delete() )
+        if ( to.exists() && !deleteLegacyStyle( to ) )
         {
             throw new IOException( "Failed to delete " + to + " while trying to rename " + from );
         }
@@ -1728,7 +1784,7 @@ public class FileUtils
         if ( !from.renameTo( to ) )
         {
             copyFile( from, to );
-            if ( !from.delete() )
+            if ( !deleteLegacyStyle( from ) )
             {
                 throw new IOException( "Failed to delete " + from + " while trying to rename it." );
             }
@@ -1798,30 +1854,35 @@ public class FileUtils
      * @param wrappers array of {@link FilterWrapper}
      * @throws IOException if an IO error occurs during copying or filtering
      */
-    public static void copyFile( @Nonnull File from, @Nonnull File to, @Nullable String encoding, @Nullable FilterWrapper... wrappers )
+    public static void copyFile( @Nonnull File from, @Nonnull File to, @Nullable String encoding,
+                                 @Nullable FilterWrapper... wrappers )
         throws IOException
     {
         copyFile( from, to, encoding, wrappers, false );
     }
 
-    public static abstract class FilterWrapper
+    /**
+     * 
+     */
+    public abstract static class FilterWrapper
     {
         public abstract Reader getReader( Reader fileReader );
     }
 
     /**
-     * <b>If wrappers is null or empty, the file will be copy only if to.lastModified() < from.lastModified() or if overwrite is true</b>
+     * <b>If wrappers is null or empty, the file will be copy only if to.lastModified() < from.lastModified() or if
+     * overwrite is true</b>
      *
-     * @param from      the file to copy
-     * @param to        the destination file
-     * @param encoding  the file output encoding (only if wrappers is not empty)
-     * @param wrappers  array of {@link FilterWrapper}
-     * @param overwrite if true and f wrappers is null or empty, the file will be copy
-     *                  enven if to.lastModified() < from.lastModified()
+     * @param from the file to copy
+     * @param to the destination file
+     * @param encoding the file output encoding (only if wrappers is not empty)
+     * @param wrappers array of {@link FilterWrapper}
+     * @param overwrite if true and f wrappers is null or empty, the file will be copy enven if to.lastModified() <
+     *            from.lastModified()
      * @throws IOException if an IO error occurs during copying or filtering
-     * 
      */
-    public static void copyFile( @Nonnull File from, @Nonnull File to, @Nullable String encoding, @Nullable FilterWrapper[] wrappers, boolean overwrite )
+    public static void copyFile( @Nonnull File from, @Nonnull File to, @Nullable String encoding,
+                                 @Nullable FilterWrapper[] wrappers, boolean overwrite )
         throws IOException
     {
         if ( wrappers != null && wrappers.length > 0 )
@@ -1877,7 +1938,7 @@ public class FileUtils
      * @return a List containing every every line not starting with # and not empty
      * @throws IOException if any
      */
-    public @Nonnull static List<String> loadFile( @Nonnull File file )
+    @Nonnull public static List<String> loadFile( @Nonnull File file )
         throws IOException
     {
         List<String> lines = new ArrayList<String>();
@@ -1919,9 +1980,8 @@ public class FileUtils
      *
      * @param f not null file
      * @return <code>false</code> if the file path contains any of forbidden Windows characters,
-     *         <code>true</code> if the Os is not Windows or if the file path respect the Windows constraints.
+     * <code>true</code> if the Os is not Windows or if the file path respect the Windows constraints.
      * @see #INVALID_CHARACTERS_FOR_WINDOWS_FILE_NAME
-     * 
      */
     private static boolean isValidWindowsFileName( @Nonnull File f )
     {
@@ -1940,4 +2000,67 @@ public class FileUtils
 
         return true;
     }
+
+    /**
+     * Checks whether a given file is a symbolic link.
+     *
+     * This only works reliably on java7 and higher. For earlier version we use a highly crappy heuristic
+     * that mostly does not work.
+     * <p>
+     * It doesn't really test for symbolic links but whether the canonical and absolute paths of the file are identical
+     * - this may lead to false positives on some platforms.
+     * </p>
+     *
+     * @param file the file to check
+     *
+     */
+    public static boolean isSymbolicLink( final @Nonnull File file )
+        throws IOException
+    {
+        if ( Java7Support.isAtLeastJava7() )
+        {
+            return Java7Support.isSymLink( file );
+        }
+        return isSymbolicLinkLegacy( file );
+    }
+
+    /**
+     * Checks whether a given file is a symbolic link.
+     *
+     * @param file the file to check
+     * @return true if and only if we reliably can say this is a symlink. This will
+     *         always return false for java versions prior to 1.7.
+     *
+     */
+    public static boolean isSymbolicLinkForSure( final @Nonnull File file )
+        throws IOException
+    {
+        return Java7Support.isAtLeastJava7() && Java7Support.isSymLink( file );
+    }
+
+    /**
+     * Checks whether a given file is a symbolic link.
+     * <p>
+     * It doesn't really test for symbolic links but whether the canonical and absolute
+     * paths of the file are identical - this may lead to false positives on some platforms.
+     *
+     * It also returns true for any file that has been reached via a symbolic link,
+     * if you decide to traverse into the symlink.
+     *
+     * As can be seen from the "return" clause of this method, there is really no
+     * guarantee of any sort from this method. Small wonder this ever got used for
+     * anything.
+     * </p>
+     *
+     * @param file the file to check
+     * @return true if the file is a symbolic link or if we're on some crappy os.
+     *         false if the file is not a symlink or we're not able to detect it.
+     */
+    static boolean isSymbolicLinkLegacy( final @Nonnull File file )
+        throws IOException
+    {
+        final File canonical = new File( file.getCanonicalPath() );
+        return !file.getAbsolutePath().equals( canonical.getPath() );
+    }
+
 }
