@@ -23,7 +23,6 @@ import javax.annotation.Nonnull;
 import javax.annotation.Nullable;
 
 import java.io.BufferedInputStream;
-import java.io.BufferedOutputStream;
 import java.io.ByteArrayInputStream;
 import java.io.ByteArrayOutputStream;
 import java.io.IOException;
@@ -84,10 +83,10 @@ import java.nio.channels.Channel;
  *
  * @author <a href="mailto:peter@apache.org">Peter Donald</a>
  * @author <a href="mailto:jefft@apache.org">Jeff Turner</a>
- * @version CVS $Revision: 1401872 $ $Date: 2012-10-24 22:45:04 +0200 (St, 24 říj 2012) $
+ * @version CVS $Revision: 1670518 $ $Date: 2015-04-01 01:38:42 +0200 (Wed, 01 Apr 2015) $
  * 
  */
-
+public final class IOUtil
 /*
  * Behold, intrepid explorers; a map of this class:
  *
@@ -118,8 +117,6 @@ import java.nio.channels.Channel;
  * each row may correspond to up to 4 methods.
  *
  */
-
-public final class IOUtil
 {
     private static final int DEFAULT_BUFFER_SIZE = 1024 * 4;
 
@@ -148,7 +145,8 @@ public final class IOUtil
      *
      * @param bufferSize Size of internal buffer to use.
      */
-    public static void copy( @Nonnull final InputStream input, @Nonnull final OutputStream output, final int bufferSize )
+    public static void copy( @Nonnull final InputStream input, @Nonnull final OutputStream output,
+                             final int bufferSize )
         throws IOException
     {
         final byte[] buffer = new byte[bufferSize];
@@ -226,7 +224,8 @@ public final class IOUtil
      *                 <a href="http://www.iana.org/assignments/character-sets">IANA
      *                 Charset Registry</a> for a list of valid encoding types.
      */
-    public static void copy( @Nonnull final InputStream input, @Nonnull final Writer output, @Nonnull final String encoding )
+    public static void copy( @Nonnull final InputStream input, @Nonnull final Writer output,
+                             @Nonnull final String encoding )
         throws IOException
     {
         final InputStreamReader in = new InputStreamReader( input, encoding );
@@ -242,7 +241,8 @@ public final class IOUtil
      *                   Charset Registry</a> for a list of valid encoding types.
      * @param bufferSize Size of internal buffer to use.
      */
-    public static void copy( @Nonnull final InputStream input, @Nonnull final Writer output, @Nonnull final String encoding, final int bufferSize )
+    public static void copy( @Nonnull final InputStream input, @Nonnull final Writer output,
+                             @Nonnull final String encoding, final int bufferSize )
         throws IOException
     {
         final InputStreamReader in = new InputStreamReader( input, encoding );
@@ -256,7 +256,7 @@ public final class IOUtil
      * Get the contents of an <code>InputStream</code> as a String.
      * The platform's default encoding is used for the byte-to-char conversion.
      */
-    public @Nonnull static String toString( @Nonnull final InputStream input )
+    @Nonnull public static String toString( @Nonnull final InputStream input )
         throws IOException
     {
         return toString( input, DEFAULT_BUFFER_SIZE );
@@ -268,7 +268,7 @@ public final class IOUtil
      *
      * @param bufferSize Size of internal buffer to use.
      */
-    public @Nonnull static String toString( @Nonnull final InputStream input, final int bufferSize )
+    @Nonnull public static String toString( @Nonnull final InputStream input, final int bufferSize )
         throws IOException
     {
         final StringWriter sw = new StringWriter();
@@ -283,7 +283,7 @@ public final class IOUtil
      *                 <a href="http://www.iana.org/assignments/character-sets">IANA
      *                 Charset Registry</a> for a list of valid encoding types.
      */
-    public @Nonnull static String toString( @Nonnull final InputStream input, @Nonnull final String encoding )
+    @Nonnull public static String toString( @Nonnull final InputStream input, @Nonnull final String encoding )
         throws IOException
     {
         return toString( input, encoding, DEFAULT_BUFFER_SIZE );
@@ -297,7 +297,8 @@ public final class IOUtil
      *                   Charset Registry</a> for a list of valid encoding types.
      * @param bufferSize Size of internal buffer to use.
      */
-    public @Nonnull static String toString( @Nonnull final InputStream input, @Nonnull final String encoding, final int bufferSize )
+    @Nonnull public static String toString( @Nonnull final InputStream input, @Nonnull final String encoding,
+                                            final int bufferSize )
         throws IOException
     {
         final StringWriter sw = new StringWriter();
@@ -311,7 +312,7 @@ public final class IOUtil
     /**
      * Get the contents of an <code>InputStream</code> as a <code>byte[]</code>.
      */
-    public @Nonnull static byte[] toByteArray( @Nonnull final InputStream input )
+    @Nonnull public static byte[] toByteArray( @Nonnull final InputStream input )
         throws IOException
     {
         return toByteArray( input, DEFAULT_BUFFER_SIZE );
@@ -322,7 +323,7 @@ public final class IOUtil
      *
      * @param bufferSize Size of internal buffer to use.
      */
-    public @Nonnull static byte[] toByteArray( @Nonnull final InputStream input, final int bufferSize )
+    @Nonnull public static byte[] toByteArray( @Nonnull final InputStream input, final int bufferSize )
         throws IOException
     {
         final ByteArrayOutputStream output = new ByteArrayOutputStream();
@@ -370,7 +371,7 @@ public final class IOUtil
     /**
      * Get the contents of a <code>Reader</code> as a String.
      */
-    public @Nonnull static String toString( @Nonnull final Reader input )
+    @Nonnull public static String toString( @Nonnull final Reader input )
         throws IOException
     {
         return toString( input, DEFAULT_BUFFER_SIZE );
@@ -381,7 +382,7 @@ public final class IOUtil
      *
      * @param bufferSize Size of internal buffer to use.
      */
-    public @Nonnull static String toString( @Nonnull final Reader input, final int bufferSize )
+    @Nonnull public static String toString( @Nonnull final Reader input, final int bufferSize )
         throws IOException
     {
         final StringWriter sw = new StringWriter();
@@ -395,7 +396,7 @@ public final class IOUtil
     /**
      * Get the contents of a <code>Reader</code> as a <code>byte[]</code>.
      */
-    public @Nonnull static byte[] toByteArray( @Nonnull final Reader input )
+    @Nonnull public static byte[] toByteArray( @Nonnull final Reader input )
         throws IOException
     {
         return toByteArray( input, DEFAULT_BUFFER_SIZE );
@@ -406,7 +407,7 @@ public final class IOUtil
      *
      * @param bufferSize Size of internal buffer to use.
      */
-    public @Nonnull static byte[] toByteArray( @Nonnull final Reader input, final int bufferSize )
+    @Nonnull public static byte[] toByteArray( @Nonnull final Reader input, final int bufferSize )
         throws IOException
     {
         ByteArrayOutputStream output = new ByteArrayOutputStream();
@@ -467,7 +468,7 @@ public final class IOUtil
     /**
      * Get the contents of a <code>String</code> as a <code>byte[]</code>.
      */
-    public @Nonnull static byte[] toByteArray( @Nonnull final String input )
+    @Nonnull public static byte[] toByteArray( @Nonnull final String input )
         throws IOException
     {
         return toByteArray( input, DEFAULT_BUFFER_SIZE );
@@ -478,7 +479,7 @@ public final class IOUtil
      *
      * @param bufferSize Size of internal buffer to use.
      */
-    public @Nonnull static byte[] toByteArray( @Nonnull final String input, final int bufferSize )
+    @Nonnull public static byte[] toByteArray( @Nonnull final String input, final int bufferSize )
         throws IOException
     {
         ByteArrayOutputStream output = new ByteArrayOutputStream();
@@ -543,7 +544,8 @@ public final class IOUtil
      *                   Charset Registry</a> for a list of valid encoding types.
      * @param bufferSize Size of internal buffer to use.
      */
-    public static void copy( @Nonnull final byte[] input, @Nonnull final Writer output, @Nonnull final String encoding, final int bufferSize )
+    public static void copy( @Nonnull final byte[] input, @Nonnull final Writer output, @Nonnull final String encoding,
+                             final int bufferSize )
         throws IOException
     {
         final ByteArrayInputStream in = new ByteArrayInputStream( input );
@@ -557,7 +559,7 @@ public final class IOUtil
      * Get the contents of a <code>byte[]</code> as a String.
      * The platform's default encoding is used for the byte-to-char conversion.
      */
-    public @Nonnull static String toString( @Nonnull final byte[] input )
+    @Nonnull public static String toString( @Nonnull final byte[] input )
         throws IOException
     {
         return toString( input, DEFAULT_BUFFER_SIZE );
@@ -569,7 +571,7 @@ public final class IOUtil
      *
      * @param bufferSize Size of internal buffer to use.
      */
-    public @Nonnull static String toString( @Nonnull final byte[] input, final int bufferSize )
+    @Nonnull public static String toString( @Nonnull final byte[] input, final int bufferSize )
         throws IOException
     {
         final StringWriter sw = new StringWriter();
@@ -584,7 +586,7 @@ public final class IOUtil
      *                 <a href="http://www.iana.org/assignments/character-sets">IANA
      *                 Charset Registry</a> for a list of valid encoding types.
      */
-    public @Nonnull static String toString( @Nonnull final byte[] input, @Nonnull final String encoding )
+    @Nonnull public static String toString( @Nonnull final byte[] input, @Nonnull final String encoding )
         throws IOException
     {
         return toString( input, encoding, DEFAULT_BUFFER_SIZE );
@@ -598,7 +600,8 @@ public final class IOUtil
      *                   Charset Registry</a> for a list of valid encoding types.
      * @param bufferSize Size of internal buffer to use.
      */
-    public @Nonnull static String toString( @Nonnull final byte[] input, @Nonnull final String encoding, final int bufferSize )
+    @Nonnull public static String toString( @Nonnull final byte[] input, @Nonnull final String encoding,
+                                            final int bufferSize )
         throws IOException
     {
         final StringWriter sw = new StringWriter();
