@@ -426,7 +426,9 @@ public final class SelectorUtils
         }
 
         // Process characters before first star
+        // CHECKSTYLE_OFF: InnerAssignment
         while ( ( ch = patArr[patIdxStart] ) != '*' && strIdxStart <= strIdxEnd )
+        // CHECKSTYLE_ON: InnerAssignment
         {
             if ( ch != '?' && !equals( ch, strArr[strIdxStart], isCaseSensitive ) )
             {
@@ -450,7 +452,9 @@ public final class SelectorUtils
         }
 
         // Process characters after last star
+        // CHECKSTYLE_OFF: InnerAssignment
         while ( ( ch = patArr[patIdxEnd] ) != '*' && strIdxStart <= strIdxEnd )
+        // CHECKSTYLE_ON: InnerAssignment
         {
             if ( ch != '?' && !equals( ch, strArr[strIdxEnd], isCaseSensitive ) )
             {
@@ -575,18 +579,13 @@ public final class SelectorUtils
     }
 
 
-    @SuppressWarnings("SimplifiableIfStatement")
     static boolean matchAntPathPatternStart( @Nonnull MatchPattern pattern,
                                              @Nonnull String str,
                                              @Nonnull String separator,
                                              boolean isCaseSensitive )
     {
-        if ( separatorPatternStartSlashMismatch( pattern, str, separator ) )
-        {
-            return false;
-        }
-
-        return matchAntPathPatternStart( pattern.getTokenizedPathString(), str, separator, isCaseSensitive );
+        return !separatorPatternStartSlashMismatch( pattern, str, separator )
+            && matchAntPathPatternStart( pattern.getTokenizedPathString(), str, separator, isCaseSensitive );
     }
 
     private static String[] tokenizePathToString( @Nonnull String path, @Nonnull String separator )
@@ -606,11 +605,18 @@ public final class SelectorUtils
                                                      boolean isCaseSensitive )
     {
         String[] strDirs = tokenizePathToString( str, separator );
+        return matchAntPathPatternStart( patDirs, strDirs, isCaseSensitive );
+    }
+
+    private static boolean matchAntPathPatternStart( @Nonnull String[] patDirs,
+                                                     @Nonnull String[] tokenizedFileName,
+                                                     boolean isCaseSensitive )
+    {
 
         int patIdxStart = 0;
         int patIdxEnd = patDirs.length - 1;
         int strIdxStart = 0;
-        int strIdxEnd = strDirs.length - 1;
+        int strIdxEnd = tokenizedFileName.length - 1;
 
         // up to first '**'
         while ( patIdxStart <= patIdxEnd && strIdxStart <= strIdxEnd )
@@ -620,7 +626,7 @@ public final class SelectorUtils
             {
                 break;
             }
-            if ( !match( patDir, strDirs[strIdxStart], isCaseSensitive ) )
+            if ( !match( patDir, tokenizedFileName[strIdxStart], isCaseSensitive ) )
             {
                 return false;
             }
@@ -785,8 +791,8 @@ public final class SelectorUtils
             && pattern.startsWith( ANT_HANDLER_PREFIX ) && pattern.endsWith( PATTERN_HANDLER_SUFFIX );
     }
 
-    static boolean matchAntPathPattern( @Nonnull MatchPattern matchPattern, @Nonnull String str, @Nonnull String separator,
-                                        boolean isCaseSensitive )
+    static boolean matchAntPathPattern( @Nonnull MatchPattern matchPattern, @Nonnull String str,
+                                        @Nonnull String separator, boolean isCaseSensitive )
     {
         if ( separatorPatternStartSlashMismatch( matchPattern, str, separator ) )
         {
