@@ -19,6 +19,7 @@ package org.apache.maven.shared.utils.io;
  * under the License.
  */
 
+import org.apache.maven.shared.utils.Os;
 import org.apache.maven.shared.utils.testhelpers.FileTestHelper;
 import org.hamcrest.CoreMatchers;
 import org.junit.Before;
@@ -28,7 +29,14 @@ import org.junit.Test;
 import org.junit.rules.TemporaryFolder;
 import org.junit.rules.TestName;
 
-import java.io.*;
+import java.io.BufferedOutputStream;
+import java.io.File;
+import java.io.FileInputStream;
+import java.io.FileNotFoundException;
+import java.io.FileOutputStream;
+import java.io.IOException;
+import java.io.InputStream;
+import java.io.OutputStream;
 import java.net.URL;
 import java.util.Arrays;
 import java.util.HashSet;
@@ -36,9 +44,13 @@ import java.util.List;
 
 import static org.hamcrest.CoreMatchers.is;
 import static org.hamcrest.CoreMatchers.not;
+import static org.junit.Assert.assertFalse;
 import static org.junit.Assert.assertThat;
+import static org.junit.Assert.assertTrue;
 import static org.junit.Assert.fail;
+import static org.junit.Assume.assumeFalse;
 import static org.junit.Assume.assumeThat;
+import static org.junit.Assume.assumeTrue;
 import static org.junit.matchers.JUnitMatchers.containsString;
 import static org.junit.matchers.JUnitMatchers.hasItems;
 
@@ -182,8 +194,8 @@ public class FileUtilsTest
     public void toFile3()
         throws Exception
     {
-        assertThat( FileUtils.toFile( null ), CoreMatchers.<File> nullValue() );
-        assertThat( FileUtils.toFile( new URL( "http://jakarta.apache.org" ) ), CoreMatchers.<File> nullValue() );
+        assertThat( FileUtils.toFile( null ), CoreMatchers.nullValue() );
+        assertThat( FileUtils.toFile( new URL( "http://jakarta.apache.org" ) ), CoreMatchers.nullValue() );
     }
 
     @Test( expected = NumberFormatException.class )
@@ -422,6 +434,58 @@ public class FileUtilsTest
             testFile1.lastModified() == destination.lastModified());*/
     }
 
+    @Test
+    public void copyFileThatIsSymlink()
+        throws Exception
+    {
+        assumeTrue( Java7Support.isAtLeastJava7() );
+        assumeFalse( Os.isFamily( Os.FAMILY_WINDOWS ) );
+
+        File destination = new File( tempFolder.getRoot(), "symCopy.txt" );
+
+        File testDir = SymlinkTestSetup.createStandardSymlinkTestDir( new File( "target/test/symlinkCopy" ) );
+
+        FileUtils.copyFile( new File( testDir, "symR" ), destination );
+        assertTrue( Java7Support.isSymLink(  destination ));
+    }
+
+
+
+    @Test
+    public void deleteFile()
+        throws Exception
+    {
+        File destination = new File( tempFolder.getRoot(), "copy1.txt" );
+        FileUtils.copyFile( testFile1, destination );
+        FileUtils.delete( destination );
+        assertThat( "Check Exist", destination.exists(), is( false ) );
+    }
+
+    @Test(expected = IOException.class)
+    public void deleteFileNofile()
+        throws Exception
+    {
+        File destination = new File( "abc/cde" );
+        FileUtils.delete( destination );
+    }
+
+    @Test
+    public void deleteFileLegacy()
+        throws Exception
+    {
+        File destination = new File( tempFolder.getRoot(), "copy1.txt" );
+        FileUtils.copyFile( testFile1, destination );
+        assertTrue( FileUtils.deleteLegacyStyle( destination ) );
+    }
+
+    @Test
+    public void deleteFileLegacyNofile()
+        throws Exception
+    {
+        File destination = new File( "abc/cde" );
+        assertFalse( FileUtils.deleteLegacyStyle( destination ) );
+    }
+
     @Test
     public void copyFile2()
         throws Exception
@@ -1333,6 +1397,29 @@ public class FileUtilsTest
         assertThat( FileUtils.extension( "C:\\test\\foo.bar.txt" ), is( "txt" ) );
     }
 
+    @Test
+    @Ignore("Wait until we can run with assembly 2.5 which will support symlinks properly")
+    public void isASymbolicLink()
+        throws IOException
+    {
+        // This testcase will pass when running under java7 or higher
+        assumeThat( Os.isFamily(Os.FAMILY_WINDOWS), is(false) );
+
+        File file = new File( "src/test/resources/symlinks/src/symDir" );
+        assertTrue(FileUtils.isSymbolicLink(file  ));
+        assertTrue(FileUtils.isSymbolicLinkLegacy(file  ));
+    }
+
+    @Test
+    @Ignore("Wait until we can run with assembly 2.5 which will support symlinks properly")
+    public void notASymbolicLink()
+        throws IOException
+    {
+        File file = new File( "src/test/resources/symlinks/src/" );
+        assertFalse(FileUtils.isSymbolicLink(file  ));
+        assertFalse(FileUtils.isSymbolicLinkLegacy(file  ));
+    }
+
     @Test
     public void extensionUnixRootPathOnUnix()
         throws Exception
