@@ -25,6 +25,7 @@ import java.lang.reflect.Constructor;
 
 import static org.hamcrest.CoreMatchers.*;
 import static org.junit.Assert.assertThat;
+import static org.junit.Assert.assertTrue;
 import static org.junit.Assert.fail;
 
 import static org.apache.maven.shared.utils.testhelpers.ExceptionHelper.*;
@@ -101,7 +102,7 @@ public class ReflectorTest
     public void newInstanceProtectedConstructor()
         throws Exception
     {
-        reflector.newInstance( ReflectorTestHelper.class, new Object[]{ Integer.valueOf( 0 ) } );
+        reflector.newInstance( ReflectorTestHelper.class, new Object[]{ 0 } );
     }
 
     @Test( expected = IllegalArgumentException.class )
@@ -109,15 +110,15 @@ public class ReflectorTest
     public void newInstanceProtectedConstructorThrowsSomething()
         throws Exception
     {
-        reflector.newInstance( ReflectorTestHelper.class, new Object[]{ Integer.valueOf( 1 ) } );
+        reflector.newInstance( ReflectorTestHelper.class, new Object[]{ 1 } );
     }
 
     @Test
     public void newInstancePublicConstructor()
         throws Exception
     {
-        assertThat( reflector.newInstance( ReflectorTestHelper.class, new Object[]{ "" } ),
-                    is( ReflectorTestHelper.class ) );
+        assertTrue( reflector.newInstance( ReflectorTestHelper.class, new Object[]{ "" } )
+                    instanceof ReflectorTestHelper );
     }
 
     @Test( expected = NullPointerException.class )
@@ -207,7 +208,7 @@ public class ReflectorTest
     public void getSingletonProtectedMethod()
         throws Exception
     {
-        reflector.getSingleton( ReflectorTestHelper.class, new Object[]{ Integer.valueOf( 0 ) } );
+        reflector.getSingleton( ReflectorTestHelper.class, new Object[]{ 0 } );
     }
 
     @Test( expected = IllegalArgumentException.class )
@@ -215,15 +216,15 @@ public class ReflectorTest
     public void getSingletonProtectedMethodThrowsSomething()
         throws Exception
     {
-        reflector.getSingleton( ReflectorTestHelper.class, new Object[]{ Integer.valueOf( 1 ) } );
+        reflector.getSingleton( ReflectorTestHelper.class, new Object[]{ 1 } );
     }
 
     @Test
     public void getSingletonPublicMethod()
         throws Exception
     {
-        assertThat( reflector.getSingleton( ReflectorTestHelper.class, new Object[]{ "" } ),
-                    is( ReflectorTestHelper.class ) );
+        assertTrue( reflector.getSingleton( ReflectorTestHelper.class, new Object[]{ "" } )
+                    instanceof ReflectorTestHelper );
     }
 
     @Test( expected = NullPointerException.class )
@@ -252,8 +253,8 @@ public class ReflectorTest
     public void getSingletonNonStaticMethod()
         throws Exception
     {
-        assertThat( reflector.getSingleton( ReflectorTestHelper.class, new Object[]{ "", Boolean.FALSE } ),
-                    is( ReflectorTestHelper.class ) );
+        assertTrue( reflector.getSingleton( ReflectorTestHelper.class, new Object[]{ "", Boolean.FALSE } )
+                    instanceof ReflectorTestHelper );
     }
 
     //// invoke( Object, String, Object[] )
@@ -319,7 +320,7 @@ public class ReflectorTest
         throws Exception
     {
         Object object = new Object();
-        assertThat( reflector.invoke( object, "hashCode", null ), is( (Object) Integer.valueOf( object.hashCode() ) ) );
+        assertThat( reflector.invoke( object, "hashCode", null ), is( (Object) object.hashCode() ) );
     }
 
     @Test
@@ -328,7 +329,7 @@ public class ReflectorTest
     {
         Object object = new Object();
         assertThat( reflector.invoke( object, "hashCode", new Object[0] ),
-                    is( (Object) Integer.valueOf( object.hashCode() ) ) );
+                    is( (Object) object.hashCode() ) );
     }
 
     @Test( expected = ReflectorException.class )
@@ -851,7 +852,7 @@ public class ReflectorTest
     public void invokeStaticProtectedMethod()
         throws Exception
     {
-        reflector.invokeStatic( ReflectorTestHelper.class, "getInstance", new Object[]{ Integer.valueOf( 0 ) } );
+        reflector.invokeStatic( ReflectorTestHelper.class, "getInstance", new Object[]{ 0 } );
     }
 
     @Test( expected = IllegalArgumentException.class )
@@ -859,15 +860,15 @@ public class ReflectorTest
     public void invokeStaticProtectedMethodThrowsSomething()
         throws Exception
     {
-        reflector.invokeStatic( ReflectorTestHelper.class, "getInstance", new Object[]{ Integer.valueOf( 1 ) } );
+        reflector.invokeStatic( ReflectorTestHelper.class, "getInstance", new Object[]{ 1 } );
     }
 
     @Test
     public void invokeStaticPublicMethod()
         throws Exception
     {
-        assertThat( reflector.invokeStatic( ReflectorTestHelper.class, "getInstance", new Object[]{ "" } ),
-                    is( ReflectorTestHelper.class ) );
+        assertTrue( reflector.invokeStatic( ReflectorTestHelper.class, "getInstance", new Object[]{ "" } )
+                    instanceof ReflectorTestHelper );
     }
 
     @Test( expected = NullPointerException.class )
@@ -896,9 +897,9 @@ public class ReflectorTest
     public void invokeStaticNonStaticMethod()
         throws Exception
     {
-        assertThat(
-            reflector.invokeStatic( ReflectorTestHelper.class, "getInstance", new Object[]{ "", Boolean.FALSE } ),
-            is( ReflectorTestHelper.class ) );
+        assertTrue(
+            reflector.invokeStatic( ReflectorTestHelper.class, "getInstance", new Object[]{ "", Boolean.FALSE } )
+            instanceof ReflectorTestHelper );
     }
 
     //// getConstructor( Class, Class[] )
